@@ -7,25 +7,13 @@ import time
 
 def find_elements_by_text(driver, text, tag_name=''):
     elements = []
-    text_elements = []
     if len(tag_name) > 0:
-        text_elements = driver.find_elements_by_xpath(
+        elements = driver.find_elements_by_xpath(
             "//{tag_name}//*[text()='{text}']|//{tag_name}//*[@value='{text}']|//{tag_name}//*[@placeholder='{text}']".format(
                 tag_name=tag_name, text=text))
     else:
-        text_elements = driver.find_elements_by_xpath(
+        elements = driver.find_elements_by_xpath(
             "//*[text()='{0}']|//*[@value='{0}']|//*[@placeholder='{0}']".format(text))
-    if text_elements and len(text_elements) > 0:
-        elements.extend(text_elements)
-
-    #     value_elements = driver.find_elements_by_xpath("//*[@value='{0}']".format(text))
-    #     if value_elements and len(value_elements) > 0:
-    #         elements.extend(value_elements)
-
-    #     placeholder_elements = driver.find_elements_by_xpath("//*[@placeholder='{0}']".format(text))
-    #     if placeholder_elements and len(placeholder_elements) > 0:
-    #         elements.extend(placeholder_elements)
-
     return elements
 
 
@@ -116,7 +104,7 @@ def find_max_probability_element(elements, anchor_element, anchor_type=''):
 
 
 def click_element(web_driver, text, anchor_type=''):
-    driver.implicitly_wait(1)  # seconds
+    web_driver.implicitly_wait(1)  # seconds
     element = find_element(web_driver, text, anchor_type)
     if element:
         element.click()
